@@ -362,7 +362,7 @@ mod test {
     }
 
     #[test]
-    #[cfg(unix)]
+    #[cfg(posix)]
     fn set_default_secret_smb() {
         let mut params = FileTransferParams::new(
             FileTransferProtocol::Scp,
