@@ -151,7 +151,7 @@ impl AuthActivity {
         if params.address.is_empty() {
             return Err("Invalid address");
         }
-        #[cfg(unix)]
+        #[cfg(posix)]
         if params.port == 0 {
             return Err("Invalid port");
         }
