@@ -269,9 +269,9 @@ impl AuthActivity {
                     .active(match self.host_bridge_input_mask() {
                         InputMask::Localhost => unreachable!(),
                         InputMask::Generic => &Id::HostBridge(AuthFormId::RemoteDirectory),
-                        #[cfg(unix)]
+                        #[cfg(posix)]
                         InputMask::Smb => &Id::HostBridge(AuthFormId::SmbWorkgroup),
-                        #[cfg(windows)]
+                        #[cfg(win)]
                         InputMask::Smb => &Id::HostBridge(AuthFormId::RemoteDirectory),
                         InputMask::AwsS3 => unreachable!("this shouldn't happen (password on s3)"),
                         InputMask::Kube => unreachable!("this shouldn't happen (password on kube)"),
@@ -285,9 +285,9 @@ impl AuthActivity {
                     .active(match self.remote_input_mask() {
                         InputMask::Localhost => unreachable!(),
                         InputMask::Generic => &Id::Remote(AuthFormId::RemoteDirectory),
-                        #[cfg(unix)]
+                        #[cfg(posix)]
                         InputMask::Smb => &Id::Remote(AuthFormId::SmbWorkgroup),
-                        #[cfg(windows)]
+                        #[cfg(win)]
                         InputMask::Smb => &Id::Remote(AuthFormId::RemoteDirectory),
                         InputMask::AwsS3 => unreachable!("this shouldn't happen (password on s3)"),
                         InputMask::Kube => unreachable!("this shouldn't happen (password on kube)"),
@@ -400,9 +400,9 @@ impl AuthActivity {
                     .active(match self.host_bridge_input_mask() {
                         InputMask::Localhost => unreachable!(),
                         InputMask::Generic => &Id::HostBridge(AuthFormId::Password),
-                        #[cfg(unix)]
+                        #[cfg(posix)]
                         InputMask::Smb => &Id::HostBridge(AuthFormId::SmbWorkgroup),
-                        #[cfg(windows)]
+                        #[cfg(win)]
                         InputMask::Smb => &Id::HostBridge(AuthFormId::Password),
                         InputMask::Kube => &Id::HostBridge(AuthFormId::KubeClientKey),
                         InputMask::AwsS3 => &Id::HostBridge(AuthFormId::S3NewPathStyle),
@@ -416,9 +416,9 @@ impl AuthActivity {
                     .active(match self.remote_input_mask() {
                         InputMask::Localhost => unreachable!(),
                         InputMask::Generic => &Id::Remote(AuthFormId::Password),
-                        #[cfg(unix)]
+                        #[cfg(posix)]
                         InputMask::Smb => &Id::Remote(AuthFormId::SmbWorkgroup),
-                        #[cfg(windows)]
+                        #[cfg(win)]
                         InputMask::Smb => &Id::Remote(AuthFormId::Password),
                         InputMask::Kube => &Id::Remote(AuthFormId::KubeClientKey),
                         InputMask::AwsS3 => &Id::Remote(AuthFormId::S3NewPathStyle),
@@ -760,28 +760,28 @@ impl AuthActivity {
                 };
                 assert!(self.app.active(id).is_ok());
             }
-            #[cfg(unix)]
+            #[cfg(posix)]
             UiMsg::HostBridge(UiAuthFormMsg::SmbWorkgroupDown) => {
                 assert!(self
                     .app
                     .active(&Id::HostBridge(AuthFormId::RemoteDirectory))
                     .is_ok());
             }
-            #[cfg(unix)]
+            #[cfg(posix)]
             UiMsg::Remote(UiAuthFormMsg::SmbWorkgroupDown) => {
                 assert!(self
                     .app
                     .active(&Id::Remote(AuthFormId::RemoteDirectory))
                     .is_ok());
             }
-            #[cfg(unix)]
+            #[cfg(posix)]
             UiMsg::HostBridge(UiAuthFormMsg::SmbWorkgroupUp) => {
                 assert!(self
                     .app
                     .active(&Id::HostBridge(AuthFormId::Password))
                     .is_ok());
             }
-            #[cfg(unix)]
+            #[cfg(posix)]
             UiMsg::Remote(UiAuthFormMsg::SmbWorkgroupUp) => {
                 assert!(self.app.active(&Id::Remote(AuthFormId::Password)).is_ok());
             }
