@@ -6,12 +6,14 @@
 // Ext
 use remotefs::fs::{File, UnixPex};
 use tuirealm::event::{Key, KeyEvent, KeyModifiers};
-use tuirealm::tui::layout::{Constraint, Direction, Layout};
-use tuirealm::tui::widgets::Clear;
-use tuirealm::{Sub, SubClause, SubEventClause};
+use tuirealm::props::{PropPayload, PropValue, TextSpan};
+use tuirealm::ratatui::layout::{Constraint, Direction, Layout};
+use tuirealm::ratatui::widgets::Clear;
+use tuirealm::{AttrValue, Attribute, Sub, SubClause, SubEventClause};
 use unicode_width::UnicodeWidthStr;
 
 use super::browser::{FileExplorerTab, FoundExplorerTab};
+use super::components::ATTR_FILES;
 use super::{components, Context, FileTransferActivity, Id};
 use crate::explorer::FileSorting;
 use crate::utils::ui::{Popup, Size};
@@ -42,7 +44,7 @@ impl FileTransferActivity {
         assert!(self
             .app
             .mount(
-                Id::ExplorerLocal,
+                Id::ExplorerHostBridge,
                 Box::new(components::ExplorerLocal::new(
                     "",
                     &[],
@@ -79,12 +81,12 @@ impl FileTransferActivity {
         self.refresh_local_status_bar();
         self.refresh_remote_status_bar();
         // Update components
-        self.update_local_filelist();
-        self.update_remote_filelist();
+        self.update_host_bridge_filelist();
+        // self.update_remote_filelist();
         // Global listener
         self.mount_global_listener();
         // Give focus to local explorer
-        assert!(self.app.active(&Id::ExplorerLocal).is_ok());
+        assert!(self.app.active(&Id::ExplorerHostBridge).is_ok());
     }
 
     // -- view
@@ -104,7 +106,7 @@ impl FileTransferActivity {
                     ]
                     .as_ref(),
                 )
-                .split(f.size());
+                .split(f.area());
             // main chunks
             let main_chunks = Layout::default()
                 .direction(Direction::Vertical)
@@ -139,7 +141,7 @@ impl FileTransferActivity {
             if matches!(self.browser.found_tab(), Some(FoundExplorerTab::Local)) {
                 self.app.view(&Id::ExplorerFind, f, tabs_chunks[0]);
             } else {
-                self.app.view(&Id::ExplorerLocal, f, tabs_chunks[0]);
+                self.app.view(&Id::ExplorerHostBridge, f, tabs_chunks[0]);
             }
             // @! Remote explorer (Find or default)
             if matches!(self.browser.found_tab(), Some(FoundExplorerTab::Remote)) {
@@ -150,80 +152,81 @@ impl FileTransferActivity {
             // Draw log box
             self.app.view(&Id::Log, f, bottom_chunks[1]);
             // Draw status bar
-            self.app.view(&Id::StatusBarLocal, f, status_bar_chunks[0]);
+            self.app
+                .view(&Id::StatusBarHostBridge, f, status_bar_chunks[0]);
             self.app.view(&Id::StatusBarRemote, f, status_bar_chunks[1]);
             // @! Draw popups
             if self.app.mounted(&Id::FatalPopup) {
                 let popup = Popup(
                     Size::Percentage(50),
-                    self.calc_popup_height(Id::FatalPopup, f.size().width, f.size().height),
+                    self.calc_popup_height(Id::FatalPopup, f.area().width, f.area().height),
                 )
-                .draw_in(f.size());
+                .draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::FatalPopup, f, popup);
             } else if self.app.mounted(&Id::CopyPopup) {
-                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::CopyPopup, f, popup);
             } else if self.app.mounted(&Id::ChmodPopup) {
-                let popup = Popup(Size::Percentage(50), Size::Unit(12)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(50), Size::Unit(12)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::ChmodPopup, f, popup);
-            } else if self.app.mounted(&Id::FindPopup) {
-                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.size());
+            } else if self.app.mounted(&Id::FilterPopup) {
+                let popup = Popup(Size::Percentage(50), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
-                self.app.view(&Id::FindPopup, f, popup);
+                self.app.view(&Id::FilterPopup, f, popup);
             } else if self.app.mounted(&Id::GotoPopup) {
-                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::GotoPopup, f, popup);
             } else if self.app.mounted(&Id::MkdirPopup) {
-                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::MkdirPopup, f, popup);
             } else if self.app.mounted(&Id::NewfilePopup) {
-                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::NewfilePopup, f, popup);
             } else if self.app.mounted(&Id::OpenWithPopup) {
-                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::OpenWithPopup, f, popup);
             } else if self.app.mounted(&Id::RenamePopup) {
-                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::RenamePopup, f, popup);
             } else if self.app.mounted(&Id::SaveAsPopup) {
-                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::SaveAsPopup, f, popup);
             } else if self.app.mounted(&Id::SymlinkPopup) {
-                let popup = Popup(Size::Percentage(50), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(50), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::SymlinkPopup, f, popup);
             } else if self.app.mounted(&Id::ExecPopup) {
-                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(40), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::ExecPopup, f, popup);
             } else if self.app.mounted(&Id::FileInfoPopup) {
-                let popup = Popup(Size::Percentage(50), Size::Percentage(50)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(50), Size::Percentage(50)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::FileInfoPopup, f, popup);
             } else if self.app.mounted(&Id::ProgressBarPartial) {
-                let popup = Popup(Size::Percentage(50), Size::Percentage(20)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(50), Size::Percentage(20)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 let popup_chunks = Layout::default()
@@ -239,14 +242,14 @@ impl FileTransferActivity {
                 self.app.view(&Id::ProgressBarFull, f, popup_chunks[0]);
                 self.app.view(&Id::ProgressBarPartial, f, popup_chunks[1]);
             } else if self.app.mounted(&Id::DeletePopup) {
-                let popup = Popup(Size::Percentage(30), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(30), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::DeletePopup, f, popup);
             } else if self.app.mounted(&Id::ReplacePopup) {
                 // NOTE: handle extended / normal modes
                 if self.is_radio_replace_extended() {
-                    let popup = Popup(Size::Percentage(50), Size::Percentage(50)).draw_in(f.size());
+                    let popup = Popup(Size::Percentage(50), Size::Percentage(50)).draw_in(f.area());
                     f.render_widget(Clear, popup);
                     let popup_chunks = Layout::default()
                         .direction(Direction::Vertical)
@@ -262,57 +265,65 @@ impl FileTransferActivity {
                         .view(&Id::ReplacingFilesListPopup, f, popup_chunks[0]);
                     self.app.view(&Id::ReplacePopup, f, popup_chunks[1]);
                 } else {
-                    let popup = Popup(Size::Percentage(50), Size::Unit(3)).draw_in(f.size());
+                    let popup = Popup(Size::Percentage(50), Size::Unit(3)).draw_in(f.area());
                     f.render_widget(Clear, popup);
                     // make popup
                     self.app.view(&Id::ReplacePopup, f, popup);
                 }
             } else if self.app.mounted(&Id::DisconnectPopup) {
-                let popup = Popup(Size::Percentage(30), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(30), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::DisconnectPopup, f, popup);
             } else if self.app.mounted(&Id::QuitPopup) {
-                let popup = Popup(Size::Percentage(30), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(30), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::QuitPopup, f, popup);
             } else if self.app.mounted(&Id::WatchedPathsList) {
-                let popup = Popup(Size::Percentage(60), Size::Percentage(50)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(60), Size::Percentage(50)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::WatchedPathsList, f, popup);
             } else if self.app.mounted(&Id::WatcherPopup) {
-                let popup = Popup(Size::Percentage(60), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(60), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::WatcherPopup, f, popup);
             } else if self.app.mounted(&Id::SortingPopup) {
-                let popup = Popup(Size::Percentage(50), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(50), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::SortingPopup, f, popup);
             } else if self.app.mounted(&Id::ErrorPopup) {
                 let popup = Popup(
                     Size::Percentage(50),
-                    self.calc_popup_height(Id::ErrorPopup, f.size().width, f.size().height),
+                    self.calc_popup_height(Id::ErrorPopup, f.area().width, f.area().height),
                 )
-                .draw_in(f.size());
+                .draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::ErrorPopup, f, popup);
             } else if self.app.mounted(&Id::WaitPopup) {
-                let popup = Popup(Size::Percentage(50), Size::Unit(3)).draw_in(f.size());
+                let wait_popup_lines = self
+                    .app
+                    .query(&Id::WaitPopup, Attribute::Text)
+                    .map(|x| x.map(|x| x.unwrap_payload().unwrap_vec().len()))
+                    .unwrap_or_default()
+                    .unwrap_or(1) as u16;
+
+                let popup =
+                    Popup(Size::Percentage(50), Size::Unit(2 + wait_popup_lines)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::WaitPopup, f, popup);
             } else if self.app.mounted(&Id::SyncBrowsingMkdirPopup) {
-                let popup = Popup(Size::Percentage(60), Size::Unit(3)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(60), Size::Unit(3)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::SyncBrowsingMkdirPopup, f, popup);
             } else if self.app.mounted(&Id::KeybindingsPopup) {
-                let popup = Popup(Size::Percentage(50), Size::Percentage(80)).draw_in(f.size());
+                let popup = Popup(Size::Percentage(50), Size::Percentage(80)).draw_in(f.area());
                 f.render_widget(Clear, popup);
                 // make popup
                 self.app.view(&Id::KeybindingsPopup, f, popup);
@@ -392,6 +403,38 @@ impl FileTransferActivity {
         assert!(self.app.active(&Id::WaitPopup).is_ok());
     }
 
+    pub(super) fn mount_walkdir_wait(&mut self) {
+        let color = self.theme().misc_info_dialog;
+        assert!(self
+            .app
+            .remount(
+                Id::WaitPopup,
+                Box::new(components::WalkdirWaitPopup::new(
+                    "Scanning current directory…",
+                    color
+                )),
+                vec![],
+            )
+            .is_ok());
+        assert!(self.app.active(&Id::WaitPopup).is_ok());
+
+        self.view();
+    }
+
+    pub(super) fn update_walkdir_entries(&mut self, entries: usize) {
+        let text = format!("Scanning current directory… ({entries} items found)",);
+        let _ = self.app.attr(
+            &Id::WaitPopup,
+            Attribute::Text,
+            AttrValue::Payload(PropPayload::Vec(vec![
+                PropValue::TextSpan(TextSpan::from(text)),
+                PropValue::TextSpan(TextSpan::from("Press 'CTRL+C' to abort")),
+            ])),
+        );
+
+        self.view();
+    }
+
     pub(super) fn mount_blocking_wait<S: AsRef<str>>(&mut self, text: S) {
         self.mount_wait(text);
         self.view();
@@ -459,6 +502,23 @@ impl FileTransferActivity {
         let _ = self.app.umount(&Id::ChmodPopup);
     }
 
+    pub(super) fn umount_filter(&mut self) {
+        let _ = self.app.umount(&Id::FilterPopup);
+    }
+
+    pub(super) fn mount_filter(&mut self) {
+        let input_color = self.theme().misc_input_dialog;
+        assert!(self
+            .app
+            .remount(
+                Id::FilterPopup,
+                Box::new(components::FilterPopup::new(input_color)),
+                vec![],
+            )
+            .is_ok());
+        assert!(self.app.active(&Id::FilterPopup).is_ok());
+    }
+
     pub(super) fn mount_copy(&mut self) {
         let input_color = self.theme().misc_input_dialog;
         assert!(self
@@ -493,10 +553,10 @@ impl FileTransferActivity {
         let _ = self.app.umount(&Id::ExecPopup);
     }
 
-    pub(super) fn mount_find(&mut self, search: &str) {
+    pub(super) fn mount_find(&mut self, msg: impl ToString, fuzzy_search: bool) {
         // Get color
         let (bg, fg, hg) = match self.browser.tab() {
-            FileExplorerTab::Local | FileExplorerTab::FindLocal => (
+            FileExplorerTab::HostBridge | FileExplorerTab::FindHostBridge => (
                 self.theme().transfer_local_explorer_background,
                 self.theme().transfer_local_explorer_foreground,
                 self.theme().transfer_local_explorer_highlighted,
@@ -507,18 +567,29 @@ impl FileTransferActivity {
                 self.theme().transfer_remote_explorer_highlighted,
             ),
         };
+
         // Mount component
         assert!(self
             .app
             .remount(
                 Id::ExplorerFind,
-                Box::new(components::ExplorerFind::new(
-                    format!(r#"Search results for "{search}""#),
-                    &[],
-                    bg,
-                    fg,
-                    hg
-                )),
+                if fuzzy_search {
+                    Box::new(components::ExplorerFuzzy::new(
+                        msg.to_string(),
+                        &[],
+                        bg,
+                        fg,
+                        hg,
+                    ))
+                } else {
+                    Box::new(components::ExplorerFind::new(
+                        msg.to_string(),
+                        &[],
+                        bg,
+                        fg,
+                        hg,
+                    ))
+                },
                 vec![],
             )
             .is_ok());
@@ -529,37 +600,41 @@ impl FileTransferActivity {
         let _ = self.app.umount(&Id::ExplorerFind);
     }
 
-    pub(super) fn mount_find_input(&mut self) {
-        let input_color = self.theme().misc_input_dialog;
-        assert!(self
-            .app
-            .remount(
-                Id::FindPopup,
-                Box::new(components::FindPopup::new(input_color)),
-                vec![],
-            )
-            .is_ok());
-        assert!(self.app.active(&Id::FindPopup).is_ok());
-    }
-
-    pub(super) fn umount_find_input(&mut self) {
-        // Umount input find
-        let _ = self.app.umount(&Id::FindPopup);
-    }
-
     pub(super) fn mount_goto(&mut self) {
+        // get files
+        let files = self
+            .browser
+            .explorer()
+            .iter_files()
+            .filter(|f| f.is_dir() || f.is_symlink())
+            .map(|f| f.path().to_string_lossy().to_string())
+            .collect::<Vec<String>>();
+
         let input_color = self.theme().misc_input_dialog;
         assert!(self
             .app
             .remount(
                 Id::GotoPopup,
-                Box::new(components::GoToPopup::new(input_color)),
+                Box::new(components::GotoPopup::new(input_color, files)),
                 vec![],
             )
             .is_ok());
         assert!(self.app.active(&Id::GotoPopup).is_ok());
     }
 
+    pub(super) fn update_goto(&mut self, files: Vec<String>) {
+        let payload = files
+            .into_iter()
+            .map(PropValue::Str)
+            .collect::<Vec<PropValue>>();
+
+        let _ = self.app.attr(
+            &Id::GotoPopup,
+            Attribute::Custom(ATTR_FILES),
+            AttrValue::Payload(PropPayload::Vec(payload)),
+        );
+    }
+
     pub(super) fn umount_goto(&mut self) {
         let _ = self.app.umount(&Id::GotoPopup);
     }
@@ -689,7 +764,7 @@ impl FileTransferActivity {
     pub(super) fn mount_file_sorting(&mut self) {
         let sorting_color = self.theme().transfer_status_sorting;
         let sorting: FileSorting = match self.browser.tab() {
-            FileExplorerTab::Local => self.local().get_file_sorting(),
+            FileExplorerTab::HostBridge => self.host_bridge().get_file_sorting(),
             FileExplorerTab::Remote => self.remote().get_file_sorting(),
             _ => return,
         };
@@ -827,7 +902,7 @@ impl FileTransferActivity {
         assert!(self
             .app
             .remount(
-                Id::StatusBarLocal,
+                Id::StatusBarHostBridge,
                 Box::new(components::StatusBarLocal::new(
                     &self.browser,
                     sorting_color,
@@ -992,138 +1067,34 @@ impl FileTransferActivity {
 
     /// Returns a sub clause which requires that no popup is mounted in order to be satisfied
     fn no_popup_mounted_clause() -> SubClause<Id> {
-        SubClause::And(
-            Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                Id::CopyPopup,
-            )))),
-            Box::new(SubClause::And(
-                Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                    Id::DeletePopup,
-                )))),
-                Box::new(SubClause::And(
-                    Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                        Id::DisconnectPopup,
-                    )))),
-                    Box::new(SubClause::And(
-                        Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                            Id::ErrorPopup,
-                        )))),
-                        Box::new(SubClause::And(
-                            Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                Id::ExecPopup,
-                            )))),
-                            Box::new(SubClause::And(
-                                Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                    Id::FatalPopup,
-                                )))),
-                                Box::new(SubClause::And(
-                                    Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                        Id::FileInfoPopup,
-                                    )))),
-                                    Box::new(SubClause::And(
-                                        Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                            Id::GotoPopup,
-                                        )))),
-                                        Box::new(SubClause::And(
-                                            Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                Id::KeybindingsPopup,
-                                            )))),
-                                            Box::new(SubClause::And(
-                                                Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                    Id::MkdirPopup,
-                                                )))),
-                                                Box::new(SubClause::And(
-                                                    Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                        Id::NewfilePopup,
-                                                    )))),
-                                                    Box::new(SubClause::And(
-                                                        Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                            Id::OpenWithPopup,
-                                                        )))),
-                                                        Box::new(SubClause::And(
-                                                            Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                Id::ProgressBarFull,
-                                                            )))),
-                                                            Box::new(SubClause::And(
-                                                                Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                    Id::ProgressBarPartial,
-                                                                )))),
-                                                                Box::new(SubClause::And(
-                                                                    Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                        Id::ExplorerFind,
-                                                                    )))),
-                                                                    Box::new(SubClause::And(
-                                                                        Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                            Id::QuitPopup,
-                                                                        )))),
-                                                                        Box::new(SubClause::And(
-                                                                            Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                Id::RenamePopup,
-                                                                            )))),
-                                                                            Box::new(SubClause::And(
-                                                                                Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                    Id::ReplacePopup,
-                                                                                )))),
-                                                                                Box::new(SubClause::And(
-                                                                                    Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                        Id::SaveAsPopup,
-                                                                                    )))),
-                                                                                    Box::new(SubClause::And(
-                                                                                        Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                            Id::SortingPopup,
-                                                                                        )))),
-                                                                                        Box::new(SubClause::And(
-                                                                                            Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                                Id::FindPopup,
-                                                                                            )))),
-                                                                                            Box::new(SubClause::And(
-                                                                                                Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                                    Id::SyncBrowsingMkdirPopup,
-                                                                                                )))),
-                                                                                                Box::new(SubClause::And(
-                                                                                                    Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                                        Id::SymlinkPopup,
-                                                                                                    )))),
-                                                                                                    Box::new(SubClause::And(
-                                                                                                        Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                                            Id::WatcherPopup,
-                                                                                                        )))),
-                                                                                                        Box::new(SubClause::And(
-                                                                                                            Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                                                Id::WatchedPathsList,
-                                                                                                            )))),
-                                                                                                            Box::new(SubClause::And(
-                                                                                                                Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                                                    Id::ChmodPopup,
-                                                                                                                )))),
-                                                                                                                Box::new(SubClause::Not(Box::new(SubClause::IsMounted(
-                                                                                                                    Id::WaitPopup,
-                                                                                                                )))),
-                                                                                                            )),
-                                                                                                        )),
-                                                                                                    )),
-                                                                                                )),
-                                                                                            )),
-                                                                                        )),
-                                                                                    )),
-                                                                                )),
-                                                                            )),
-                                                                        )),
-                                                                    )),
-                                                                )),
-                                                            )),
-                                                        )),
-                                                    )),
-                                                )),
-                                            )),
-                                        )),
-                                    )),
-                                )),
-                            )),
-                        )),
-                    )),
-                )),
-            )),
+        tuirealm::subclause_and_not!(
+            Id::CopyPopup,
+            Id::DeletePopup,
+            Id::DisconnectPopup,
+            Id::ErrorPopup,
+            Id::ExecPopup,
+            Id::FatalPopup,
+            Id::FileInfoPopup,
+            Id::GotoPopup,
+            Id::KeybindingsPopup,
+            Id::MkdirPopup,
+            Id::NewfilePopup,
+            Id::OpenWithPopup,
+            Id::ProgressBarFull,
+            Id::ProgressBarPartial,
+            Id::ExplorerFind,
+            Id::QuitPopup,
+            Id::RenamePopup,
+            Id::ReplacePopup,
+            Id::SaveAsPopup,
+            Id::SortingPopup,
+            Id::SyncBrowsingMkdirPopup,
+            Id::SymlinkPopup,
+            Id::WatcherPopup,
+            Id::WatchedPathsList,
+            Id::ChmodPopup,
+            Id::WaitPopup,
+            Id::FilterPopup
         )
     }
 }
